/**********************************************************************
Copyright (c) 2006 Travis Reeder and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
2008 Andy Jefferson - added getNumberOfFields(), getFieldNameForColumn()
    ...
 **********************************************************************/
package org.datanucleus.sql4o;

import com.db4o.reflect.ReflectField;

/**
 * Implementation of a row of results.
 */
public class ObjectWrapper implements Result
{
    private Object ob;

    // TODO: shouldn't hold onto this ObjectSetWrapper, might create memory leaks
    private ObjectSetWrapper objectSetWrapper;

    public ObjectWrapper(ObjectSetWrapper objectSetWrapper, Object ob)
    {
        this.objectSetWrapper = objectSetWrapper;
        this.ob = ob;
    }

    public Object getObject(int fieldIndex) throws Sql4oException
    {
        ReflectField f = objectSetWrapper.getFieldForColumn(fieldIndex);
        return getFieldValue(f, ob);
    }

    public Object getObject(String fieldName) throws Sql4oException
    {
        ReflectField f = objectSetWrapper.getFieldForColumn(fieldName);
        return getFieldValue(f, ob);
    }

    private Object getFieldValue(ReflectField f, Object ob)
    {
        return f.get(ob);
    }

    public Object getBaseObject(int objectIndex)
    {
        return ob;
    }

    /**
     * Accessor for the number of returned fields. If the user has specified particular fields then returns that number.
     * If the user specified * notation then the total number of fields is returned.
     * @return Number of fields per item
     */
    public int getNumberOfFields()
    {
    	return objectSetWrapper.getNumberOfFields();
    }

    /**
     * Accessor for the name of a field returned in an index position.
     * @param fieldIndex Position
     * @return The field name returned there
     */
    public String getFieldNameForColumn(int fieldIndex)
    {
    	return objectSetWrapper.getFieldNameForColumn(fieldIndex);
    }
}
