/**********************************************************************
Copyright (c) 2006 Travis Reeder and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.datanucleus.sql4o;

import com.db4o.ObjectContainer;

import java.util.List;

import org.datanucleus.sql4o.parser.SqlParseException;
import org.datanucleus.sql4o.parser.SqlParser;
import org.datanucleus.sql4o.query.SqlQuery;

/**
 * Core convenience class to wrap up all the functionality.
 */
public class Sql4o
{
    /**
     * Main entry point to sql4o. Takes the provided SQL query and executes it against the
     * passed ObjectContainer.
     * @param oc ObjectContainer
     * @param query The SQL query
     * @return Results from the SQL query
     * @throws SqlParseException thrown if an error occurs parsing the SQL
     * @throws Sql4oException thrown if an error occurs in execution
     */
    public static List<Result> execute(ObjectContainer oc, String query) 
    throws SqlParseException, Sql4oException
    {
        SqlQuery sqlQuery = (SqlQuery) SqlParser.parse(query);
        List<Result> results = SqlToSoda.execute(oc, sqlQuery);
        return results;
    }
}