/**********************************************************************
Copyright (c) 2006 Travis Reeder and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.datanucleus.sql4o.parser;


import java.util.List;

import org.datanucleus.sql4o.query.OrderBy;
import org.datanucleus.sql4o.query.SqlQuery;

/**
 * 
 */
public class OrderByBuilder implements Builder
{

    static final String keyword = "ORDER";

    public String getKeyword()
    {
        return keyword;
    }

    public void build(SqlQuery sq, List<String> expr, List<String> quotedStrings) throws SqlParseException
    {
        OrderBy orderBy = new OrderBy();
        // select is just a list of fields separated by commas, not necessarily by spaces, so lets split further by
        // commas
        List<String> values = SqlParser.separateCommas(expr.subList(1, expr.size()), false);

        int j = 0;
        OrderBy.Field field = new OrderBy.Field();
        // now find ascending or descending
        for (int i = 0; i < values.size(); i++)
        {
            String s = values.get(i);
            if (s.equals(","))
            {
                j = 0;
                orderBy.addField(field);
                field = new OrderBy.Field();
            }

            if (j > 1)
            {
                throw new SqlParseException("Order by clause invalid, too many parts: " + s);
            }
            if (j == 0)
            {
                field.setName(s);
            }
            else if (j == 1)
            {
                if (s.equalsIgnoreCase(OrderBy.ASC))
                {
                    field.orderAscending();
                }
                else if (s.equalsIgnoreCase(OrderBy.DESC))
                {
                    field.orderDescending();
                }
            }
            j++;
        }
        if (j == 0)
        {
            throw new SqlParseException("Invalid ORDER BY clause.");
        }
        orderBy.addField(field);
        sq.setOrderBy(orderBy);
    }
}
